@@ -21,7 +21,6 @@
 
 import logging
 import os
-from typing import Dict
 
 import click
 
@@ -56,15 +55,14 @@ class Scenario(base.Base):
 
         Initialize a new scenario using a local *cookiecutter* template for the
         driver configuration.
-    """  # noqa
+    """
 
-    def __init__(self, command_args: Dict[str, str]):
+    def __init__(self, command_args: dict[str, str]) -> None:
         """Construct Scenario."""
         self._command_args = command_args
 
-    def execute(self):
-        """
-        Execute the actions necessary to perform a `molecule init scenario` and \
+    def execute(self, action_args=None):
+        """Execute the actions necessary to perform a `molecule init scenario` and \
         returns None.
 
         :return: None
@@ -76,7 +74,7 @@ class Scenario(base.Base):
         msg = f"Initializing new scenario {scenario_name}..."
         LOG.info(msg)
         molecule_directory = config.molecule_directory(
-            os.path.join(role_directory, role_name)
+            os.path.join(role_directory, role_name),
         )
         scenario_directory = os.path.join(molecule_directory, scenario_name)
 
@@ -109,7 +107,9 @@ class Scenario(base.Base):
         self._process_templates("molecule", self._command_args, role_directory)
         for template in templates:
             self._process_templates(
-                template, self._command_args, scenario_base_directory
+                template,
+                self._command_args,
+                scenario_base_directory,
             )
 
         role_directory = os.path.join(role_directory, role_name)
@@ -135,7 +135,8 @@ def _default_scenario_exists(ctx, param, value: str):  # pragma: no cover
         return value
 
     default_scenario_directory = os.path.join(
-        "molecule", command_base.MOLECULE_DEFAULT_SCENARIO_NAME
+        "molecule",
+        command_base.MOLECULE_DEFAULT_SCENARIO_NAME,
     )
     if not os.path.exists(default_scenario_directory):
         msg = f"The default scenario not found.  Please create a scenario named '{command_base.MOLECULE_DEFAULT_SCENARIO_NAME}' first."
@@ -158,12 +159,6 @@ def _default_scenario_exists(ctx, param, value: str):  # pragma: no cover
     default=DEFAULT_DRIVER,
     help=f"Name of driver to initialize. ({DEFAULT_DRIVER})",
 )
-@click.option(
-    "--lint-name",
-    type=click.Choice(["yamllint"]),
-    default="yamllint",
-    help="Name of lint to initialize. (ansible-lint)",
-)
 @click.option(
     "--provisioner-name",
     type=click.Choice(["ansible"]),
@@ -193,7 +188,6 @@ def scenario(
     ctx,
     dependency_name,
     driver_name,
-    lint_name,
     provisioner_name,
     role_name,
     scenario_name,
@@ -206,7 +200,6 @@ def scenario(
     command_args = {
         "dependency_name": dependency_name,
         "driver_name": driver_name,
-        "lint_name": lint_name,
         "provisioner_name": provisioner_name,
         "role_name": role_name,
         "scenario_name": scenario_name,
