@@ -21,72 +21,27 @@
 
 import logging
 import os
+import shlex
+import subprocess
 
 import click
 
 from molecule import scenarios, util
-from molecule.app import app
 from molecule.command import base
 
 LOG = logging.getLogger(__name__)
 
 
 class Login(base.Base):
-    """
-    Login Command Class.
+    """Login Command Class."""
 
-    .. program:: molecule login
-
-    .. option:: molecule login
-
-        Target the default scenario.
-
-    .. program:: molecule login --scenario-name foo
-
-    .. option:: molecule login --scenario-name foo
-
-        Targeting a specific scenario.
-
-    .. program:: molecule login --host hostname
-
-    .. option:: molecule login --host hostname
-
-        Targeting a specific running host.
-
-    .. program:: molecule login --host hostname --scenario-name foo
-
-    .. option:: molecule login --host hostname --scenario-name foo
-
-        Targeting a specific running host and scenario.
-
-    .. program:: molecule --debug login
-
-    .. option:: molecule --debug login
-
-        Executing with `debug`.
-
-    .. program:: molecule --base-config base.yml login
-
-    .. option:: molecule --base-config base.yml login
-
-        Executing with a `base-config`.
-
-    .. program:: molecule --env-file foo.yml login
-
-    .. option:: molecule --env-file foo.yml login
-
-        Load an env file to read variables from when rendering
-        molecule.yml.
-    """
-
-    def __init__(self, c):
+    def __init__(self, c) -> None:
         """Construct Login."""
-        super(Login, self).__init__(c)
+        super().__init__(c)
         self._pt = None
 
-    def execute(self):
-        """
-        Execute the actions necessary to perform a `molecule login` and \
+    def execute(self, action_args=None):
+        """Execute the actions necessary to perform a `molecule login` and \
         returns None.
 
         :return: None
@@ -142,8 +97,8 @@ class Login(base.Base):
         login_options["lines"] = lines
         login_cmd = self._config.driver.login_cmd_template.format(**login_options)
 
-        cmd = f"/usr/bin/env {login_cmd}"
-        app.runtime.exec(cmd)
+        cmd = shlex.split(f"/usr/bin/env {login_cmd}")
+        subprocess.run(cmd)
 
 
 @base.click_command_ex()
