@@ -31,72 +31,14 @@ from molecule.config import DEFAULT_DRIVER
 
 LOG = logging.getLogger(__name__)
 MOLECULE_PARALLEL = os.environ.get("MOLECULE_PARALLEL", False)
+MOLECULE_PLATFORM_NAME = os.environ.get("MOLECULE_PLATFORM_NAME", None)
 
 
 class Test(base.Base):
-    """
-    Test Command Class.
+    """Test Command Class."""
 
-    .. program:: molecule test
-
-    .. option:: molecule test
-
-        Target the default scenario.
-
-    .. program:: molecule test --scenario-name foo
-
-    .. option:: molecule test --scenario-name foo
-
-        Targeting a specific scenario.
-
-    .. program:: molecule test --all
-
-    .. option:: molecule test --all
-
-        Target all scenarios.
-
-    .. option:: molecule test -- -vvv --tags foo,bar
-
-        Providing additional command line arguments to the `ansible-playbook`
-        command.  Use this option with care, as there is no sanitation or
-        validation of input.  Options passed on the CLI are combined with options
-        provided in provisioner's `options` section of `molecule.yml`.
-
-    .. program:: molecule test --destroy=always
-
-    .. option:: molecule test --destroy=always
-
-        Always destroy instances at the conclusion of a Molecule run.
-
-    .. program:: molecule --debug test
-
-    .. option:: molecule --debug test
-
-        Executing with `debug`.
-
-    .. program:: molecule --base-config base.yml test
-
-    .. option:: molecule --base-config base.yml test
-
-        Executing with a `base-config`.
-
-    .. program:: molecule --env-file foo.yml test
-
-    .. option:: molecule --env-file foo.yml test
-
-        Load an env file to read variables from when rendering
-        molecule.yml.
-
-    .. program:: molecule test --parallel
-
-    .. option:: molecule test --parallel
-
-       Run in parallelizable mode.
-    """
-
-    def execute(self):
-        """
-        Execute the actions necessary to perform a `molecule test` and \
+    def execute(self, action_args=None):
+        """Execute the actions necessary to perform a `molecule test` and \
         returns None.
 
         :return: None
@@ -109,9 +51,13 @@ class Test(base.Base):
     "--scenario-name",
     "-s",
     default=base.MOLECULE_DEFAULT_SCENARIO_NAME,
-    help="Name of the scenario to target. ({})".format(
-        base.MOLECULE_DEFAULT_SCENARIO_NAME
-    ),
+    help=f"Name of the scenario to target. ({base.MOLECULE_DEFAULT_SCENARIO_NAME})",
+)
+@click.option(
+    "--platform-name",
+    "-p",
+    default=MOLECULE_PLATFORM_NAME,
+    help="Name of the platform to target only. Default is None",
 )
 @click.option(
     "--driver-name",
@@ -138,9 +84,16 @@ class Test(base.Base):
 )
 @click.argument("ansible_args", nargs=-1, type=click.UNPROCESSED)
 def test(
-    ctx, scenario_name, driver_name, __all, destroy, parallel, ansible_args
+    ctx,
+    scenario_name,
+    driver_name,
+    __all,
+    destroy,
+    parallel,
+    ansible_args,
+    platform_name,
 ):  # pragma: no cover
-    """Test (dependency, lint, cleanup, destroy, syntax, create, prepare, converge, idempotence, side_effect, verify, cleanup, destroy)."""
+    """Test (dependency, cleanup, destroy, syntax, create, prepare, converge, idempotence, side_effect, verify, cleanup, destroy)."""
     args = ctx.obj.get("args")
     subcommand = base._get_subcommand(__name__)
     command_args = {
@@ -148,6 +101,7 @@ def test(
         "destroy": destroy,
         "subcommand": subcommand,
         "driver_name": driver_name,
+        "platform_name": platform_name,
     }
 
     if __all:
