@@ -28,8 +28,7 @@ LOG = logging.getLogger(__name__)
 
 
 class Shell(base.Base):
-    """
-    ``Shell`` is an alternate dependency manager.
+    """``Shell`` is an alternate dependency manager.
 
     It is intended to run a command in situations where `Ansible Galaxy`_
     don't suffice.
@@ -37,41 +36,40 @@ class Shell(base.Base):
     The ``command`` to execute is required, and is relative to Molecule's
     project directory when referencing a script not in $PATH.
 
-    .. note::
+    !!! note
 
         Unlike the other dependency managers, ``options`` are ignored and not
         passed to `shell`.  Additional flags/subcommands should simply be added
         to the `command`.
 
-    .. code-block:: yaml
-
+    ``` yaml
         dependency:
           name: shell
           command: path/to/command --flag1 subcommand --flag2
+    ```
 
     The dependency manager can be disabled by setting ``enabled`` to False.
 
-    .. code-block:: yaml
-
+    ``` yaml
         dependency:
           name: shell
           command: path/to/command --flag1 subcommand --flag2
           enabled: False
-
+    ```
     Environment variables can be passed to the dependency.
 
-    .. code-block:: yaml
-
+    ``` yaml
         dependency:
           name: shell
           command: path/to/command --flag1 subcommand --flag2
           env:
             FOO: bar
+    ```
     """
 
-    def __init__(self, config):
+    def __init__(self, config) -> None:
         """Construct Shell."""
-        super(Shell, self).__init__(config)
+        super().__init__(config)
         self._sh_command = None
 
         # self.command = config..config['dependency']['command']
@@ -86,7 +84,7 @@ class Shell(base.Base):
 
     def bake(self) -> None:
         """Bake a ``shell`` command so it's ready to execute."""
-        self._sh_command = BakedCommand(cmd=self.command, env=self.env)
+        self._sh_command = BakedCommand(cmd=self.command, env=self.env)  # type: ignore
 
     def execute(self, action_args=None):
         if not self.enabled:
