@@ -28,8 +28,7 @@ LOG = logging.getLogger(__name__)
 
 
 class Delegated(Driver):
-    r"""
-    The class responsible for managing delegated instances.
+    r"""The class responsible for managing delegated instances.
 
     Delegated is `not` the default driver used in Molecule.
 
@@ -37,16 +36,16 @@ class Delegated(Driver):
     create and destroy playbooks.  ``Managed`` is the default behaviour of all
     drivers.
 
-    .. code-block:: yaml
-
+    ``` yaml
         driver:
           name: delegated
+    ```
 
     However, the developer must adhere to the instance-config API. The
     developer's create playbook must provide the following instance-config
     data, and the developer's destroy playbook must reset the instance-config.
 
-    .. code-block:: yaml
+    ``` yaml
 
         - address: ssh_endpoint
           identity_file: ssh_identity_file  # mutually exclusive with password
@@ -67,6 +66,7 @@ class Delegated(Driver):
           winrm_cert_pem: <path to the credssp public certificate key>
           winrm_cert_key_pem: <path to the credssp private certificate key>
           winrm_server_cert_validation: validate/ignore
+    ```
 
     This article covers how to configure and use WinRM with Ansible:
     https://docs.ansible.com/ansible/latest/user_guide/windows_winrm.html
@@ -75,8 +75,7 @@ class Delegated(Driver):
     developers responsibility to manage the instances, and properly configure
     Molecule to connect to said instances.
 
-    .. code-block:: yaml
-
+    ``` yaml
         driver:
           name: delegated
           options:
@@ -86,23 +85,23 @@ class Delegated(Driver):
               ansible_connection: docker
         platforms:
           - name: instance-docker
+    ```
 
-    .. code-block:: bash
-
+    ``` bash
         $ docker run \
             -d \
             --name instance-docker \
             --hostname instance-docker \
             -it molecule_local/ubuntu:latest sleep infinity & wait
+    ```
 
     Use Molecule with delegated instances, which are accessible over ssh.
 
-    .. important::
+    !!! note
 
         It is the developer's responsibility to configure the ssh config file.
 
-    .. code-block:: yaml
-
+    ``` yaml
         driver:
           name: delegated
           options:
@@ -113,31 +112,31 @@ class Delegated(Driver):
               ansible_ssh_common_args: '-F /path/to/ssh-config'
         platforms:
           - name: instance
+    ```
 
     Provide the files Molecule will preserve post ``destroy`` action.
 
-    .. code-block:: yaml
-
+    ``` yaml
         driver:
           name: delegated
           safe_files:
             - foo
-
+    ```
     And in order to use localhost as molecule's target:
 
-    .. code-block:: yaml
-
+    ``` yaml
         driver:
           name: delegated
           options:
             managed: False
             ansible_connection_options:
               ansible_connection: local
+    ```
     """
 
-    def __init__(self, config=None):
+    def __init__(self, config=None) -> None:
         """Construct Delegated."""
-        super(Delegated, self).__init__(config)
+        super().__init__(config)
         self._name = "delegated"
 
     @property
@@ -157,12 +156,13 @@ class Delegated(Driver):
             connection_options = " ".join(self.ssh_connection_options)
 
             return (
-                "ssh {{address}} "
-                "-l {{user}} "
-                "-p {{port}} "
-                "-i {{identity_file}} "
-                "{}"
-            ).format(connection_options)
+                "ssh {address} "
+                "-l {user} "
+                "-p {port} "
+                "-i {identity_file} "
+                f"{connection_options}"
+            )
+        return None
 
     @property
     def default_safe_files(self):
@@ -173,12 +173,13 @@ class Delegated(Driver):
         if self.managed:
             ssh_connopts = self._get_ssh_connection_options()
             if self.options.get("ansible_connection_options", {}).get(
-                "ansible_ssh_common_args", None
+                "ansible_ssh_common_args",
+                None,
             ):
                 ssh_connopts.append(
                     self.options.get("ansible_connection_options").get(
-                        "ansible_ssh_common_args"
-                    )
+                        "ansible_ssh_common_args",
+                    ),
                 )
             return ssh_connopts
         return []
@@ -207,7 +208,7 @@ class Delegated(Driver):
                 if d.get("identity_file", None):
                     conn_dict["ansible_private_key_file"] = d.get("identity_file")
                     conn_dict["ansible_ssh_common_args"] = " ".join(
-                        self.ssh_connection_options
+                        self.ssh_connection_options,
                     )
                 if d.get("password", None):
                     conn_dict["ansible_password"] = d.get("password")
@@ -220,18 +221,18 @@ class Delegated(Driver):
                     conn_dict["ansible_winrm_cert_pem"] = d.get("winrm_cert_pem")
                 if d.get("winrm_cert_key_pem", None):
                     conn_dict["ansible_winrm_cert_key_pem"] = d.get(
-                        "winrm_cert_key_pem"
+                        "winrm_cert_key_pem",
                     )
                 if d.get("winrm_server_cert_validation", None):
                     conn_dict["ansible_winrm_server_cert_validation"] = d.get(
-                        "winrm_server_cert_validation"
+                        "winrm_server_cert_validation",
                     )
 
                 return conn_dict
 
             except StopIteration:
                 return {}
-            except IOError:
+            except OSError:
                 # Instance has yet to be provisioned , therefore the
                 # instance_config is not on disk.
                 return {}
@@ -239,7 +240,7 @@ class Delegated(Driver):
 
     def _created(self):
         if self.managed:
-            return super(Delegated, self)._created()
+            return super()._created()
         return "unknown"
 
     def _get_instance_config(self, instance_name):
