@@ -17,34 +17,33 @@
 """Iterpolation Module."""
 
 import string
-from typing import MutableMapping, Type
+from collections.abc import MutableMapping
 
 
 class InvalidInterpolation(Exception):
     """InvalidInterpolation Exception."""
 
-    def __init__(self, string: str, place: Exception):
+    def __init__(self, string: str, place: Exception) -> None:
         """Construct InvalidInterpolation."""
         self.string = string
         self.place = place
 
 
-class Interpolator(object):
-    """
-    Configuration options may contain environment variables.
+class Interpolator:
+    """Configuration options may contain environment variables.
 
     For example, suppose the shell contains ``VERIFIER_NAME=testinfra`` and
     the following molecule.yml is supplied.
 
-    .. code-block:: yaml
-
+    ```yaml
         verifier:
           - name: ${VERIFIER_NAME}
+    ```
 
     Molecule will substitute ``$VERIFIER_NAME`` with the value of the
     ``VERIFIER_NAME`` environment variable.
 
-    .. warning::
+    !!! warning
 
         If an environment variable is not set, Molecule substitutes with an
         empty string.
@@ -62,7 +61,7 @@ class Interpolator(object):
     Molecule will substitute special ``MOLECULE_`` environment variables
     defined in `molecule.yml`.
 
-    .. important::
+    !!! note
 
         Remember, the ``MOLECULE_`` namespace is reserved for Molecule.  Do not
         prefix your own variables with `MOLECULE_`.
@@ -72,8 +71,10 @@ class Interpolator(object):
     """
 
     def __init__(
-        self, templater: Type["TemplateWithDefaults"], mapping: MutableMapping
-    ):
+        self,
+        templater: type["TemplateWithDefaults"],
+        mapping: MutableMapping,
+    ) -> None:
         """Construct Interpolator."""
         self.templater = templater
         self.mapping = mapping
@@ -90,9 +91,8 @@ class TemplateWithDefaults(string.Template):
 
     idpattern = r"[_a-z][_a-z0-9]*(?::?-[^}]+)?"
 
-    # Modified from python2.7/string.py
+    # pylint: disable=too-many-return-statements
     def substitute(self, mapping, keep_string):
-
         # Helper function for .sub()
         def convert(mo):
             # Check the most common path first.
@@ -119,5 +119,7 @@ class TemplateWithDefaults(string.Template):
                 return self.delimiter
             if mo.group("invalid") is not None:
                 self._invalid(mo)
+                return None
+            return None
 
         return self.pattern.sub(convert, self.template)
