@@ -25,7 +25,7 @@ import copy
 import logging
 import os
 import shutil
-from typing import List, Optional
+from typing import Any, Optional
 
 from ansible_compat.ports import cached_property
 
@@ -38,7 +38,7 @@ LOG = logging.getLogger(__name__)
 
 class Ansible(base.Base):
     """
-    `Ansible`_ is the default provisioner.  No other provisioner will be \
+    `Ansible` is the default provisioner.  No other provisioner will be \
     supported.
 
     Molecule's provisioner manages the instances lifecycle.  However, the user
@@ -49,7 +49,7 @@ class Ansible(base.Base):
     `notest`. With the tag `molecule-idempotence-notest` tasks are only
     skipped during the idempotence action step.
 
-    .. important::
+    !!! warning
 
         Reserve the create and destroy playbooks for provisioning.  Do not
         attempt to gather facts or perform operations on the provisioned nodes
@@ -64,13 +64,13 @@ class Ansible(base.Base):
     Additional options can be passed to ``ansible-playbook`` through the options
     dict.  Any option set in this section will override the defaults.
 
-    .. important::
+    !!! note
 
         Options do not affect the create and destroy actions.
 
-    .. note::
+    !!! note
 
-        Molecule will remove any options matching '^[v]+$', and pass ``-vvv``
+        Molecule will remove any options matching `^[v]+$`, and pass ``-vvv``
         to the underlying ``ansible-playbook`` command when executing
         `molecule --debug`.
 
@@ -78,11 +78,11 @@ class Ansible(base.Base):
     However, this results in quite a bit of output.  To enable Ansible log
     output, add the following to the ``provisioner`` section of ``molecule.yml``.
 
-    .. code-block:: yaml
-
+    ``` yaml
         provisioner:
           name: ansible
           log: True
+    ```
 
     The create/destroy playbooks for Docker and Podman are bundled with
     Molecule.  These playbooks have a clean API from `molecule.yml`, and
@@ -94,8 +94,7 @@ class Ansible(base.Base):
     2. provisioner.playbooks.$action
     3. bundled_playbook.$driver_name.$action
 
-    .. code-block:: yaml
-
+    ``` yaml
         provisioner:
           name: ansible
           options:
@@ -104,30 +103,30 @@ class Ansible(base.Base):
             create: create.yml
             converge: converge.yml
             destroy: destroy.yml
+    ```
 
     Share playbooks between roles.
 
-    .. code-block:: yaml
-
+    ``` yaml
         provisioner:
           name: ansible
           playbooks:
             create: ../default/create.yml
             destroy: ../default/destroy.yml
             converge: converge.yml
+    ```
 
     Multiple driver playbooks.  In some situations a developer may choose to
     test the same role against different backends.  Molecule will choose driver
     specific create/destroy playbooks, if the determined driver has a key in
     the playbooks section of the provisioner's dict.
 
-    .. important::
+    !!! note
 
         If the determined driver has a key in the playbooks dict, Molecule will
         use this dict to resolve all provisioning playbooks (create/destroy).
 
-    .. code-block:: yaml
-
+    ``` yaml
         provisioner:
           name: ansible
           playbooks:
@@ -137,8 +136,9 @@ class Ansible(base.Base):
             create: create.yml
             destroy: destroy.yml
             converge: converge.yml
+    ```
 
-    .. important::
+    !!! note
 
         Paths in this section are converted to absolute paths, where the
         relative parent is the $scenario_directory.
@@ -148,14 +148,14 @@ class Ansible(base.Base):
     not enabled by default.  Add the following to the provisioner's ``playbooks``
     section to enable.
 
-    .. code-block:: yaml
-
+    ``` yaml
         provisioner:
           name: ansible
           playbooks:
             side_effect: side_effect.yml
+    ```
 
-    .. important::
+    !!! note
 
         This feature should be considered experimental.
 
@@ -166,12 +166,12 @@ class Ansible(base.Base):
     This can be used to bring instances into a particular state, prior to
     testing.
 
-    .. code-block:: yaml
-
+    ``` yaml
         provisioner:
           name: ansible
           playbooks:
             prepare: prepare.yml
+    ```
 
     The cleanup playbook is for cleaning up test infrastructure that may not
     be present on the instance that will be destroyed. The primary use-case
@@ -189,14 +189,14 @@ class Ansible(base.Base):
     Add the following to the provisioner's `playbooks` section
     to enable.
 
-    .. code-block:: yaml
-
+    ``` yaml
         provisioner:
           name: ansible
           playbooks:
             cleanup: cleanup.yml
+    ```
 
-    .. important::
+    !!! note
 
         This feature should be considered experimental.
 
@@ -217,22 +217,21 @@ class Ansible(base.Base):
     and converted to absolute paths, where the relative parent is the
     $scenario_directory.
 
-    .. important::
+    !!! note
 
         Paths in this section are converted to absolute paths, where the
         relative parent is the $scenario_directory.
 
-    .. code-block:: yaml
-
+    ``` yaml
         provisioner:
           name: ansible
           env:
             FOO: bar
+    ```
 
     Modifying ansible.cfg.
 
-    .. code-block:: yaml
-
+    ``` yaml
         provisioner:
           name: ansible
           config_options:
@@ -240,16 +239,16 @@ class Ansible(base.Base):
               fact_caching: jsonfile
             ssh_connection:
               scp_if_ssh: True
+    ```
 
-    .. important::
+    !!! note
 
         The following keys are disallowed to prevent Molecule from
         improperly functioning.  They can be specified through the
         provisioner's env setting described above, with the exception
         of the `privilege_escalation`.
 
-    .. code-block:: yaml
-
+    ``` yaml
         provisioner:
           name: ansible
           config_options:
@@ -258,25 +257,28 @@ class Ansible(base.Base):
               library: /path/to/library
               filter_plugins: /path/to/filter_plugins
             privilege_escalation: {}
+    ```
 
     Roles which require host/groups to have certain variables set.  Molecule
     uses the same `variables defined in a playbook`_ syntax as `Ansible`_.
 
-    .. code-block:: yaml
-
+    ``` yaml
         provisioner:
           name: ansible
           inventory:
             group_vars:
-              foo1:
+              all:
+                bar: foo
+              group1:
                 foo: bar
-              foo2:
+              group2:
                 foo: bar
                 baz:
                   qux: zzyzx
             host_vars:
-              foo1-01:
-                foo: bar
+              group1-01:
+                foo: baz
+    ```
 
     Molecule automatically generates the inventory based on the hosts defined
     under `Platforms`_. Using the ``hosts`` key allows to add extra hosts to
@@ -285,13 +287,12 @@ class Ansible(base.Base):
     A typical use case is if you want to access some variables from another
     host in the inventory (using hostvars) without creating it.
 
-    .. note::
+    !!! note
 
         The content of ``hosts`` should follow the YAML based inventory syntax:
         start with the ``all`` group and have hosts/vars/children entries.
 
-    .. code-block:: yaml
-
+    ``` yaml
         provisioner:
           name: ansible
           inventory:
@@ -300,8 +301,9 @@ class Ansible(base.Base):
                 hosts:
                   extra_host:
                     foo: hello
+    ```
 
-    .. important::
+    !!! note
 
         The extra hosts added to the inventory using this key won't be
         created/destroyed by Molecule. It is the developers responsibility
@@ -320,13 +322,13 @@ class Ansible(base.Base):
     This can be useful if you want to define extra hosts that are not managed
     by Molecule.
 
-    .. important::
+    !!! note
 
         Again, it is the developers responsibility to target the proper hosts
         in the playbook. Only the hosts defined under
         `Platforms`_ should be targeted instead of ``all``.
 
-    .. note::
+    !!! note
 
         The source directory linking is relative to the scenario's
         directory.
@@ -335,8 +337,7 @@ class Ansible(base.Base):
         schema validator will enforce this.
 
 
-    .. code-block:: yaml
-
+    ``` yaml
         provisioner:
           name: ansible
           inventory:
@@ -344,14 +345,14 @@ class Ansible(base.Base):
               hosts: ../../../inventory/hosts
               group_vars: ../../../inventory/group_vars/
               host_vars: ../../../inventory/host_vars/
+    ```
 
-    .. important::
+    !!! note
 
         You can use either `hosts`/`group_vars`/`host_vars` sections of inventory OR `links`.
         If you use both, links will win.
 
-    .. code-block:: yaml
-
+    ``` yaml
         provisioner:
           name: ansible
           hosts:
@@ -362,48 +363,67 @@ class Ansible(base.Base):
           inventory:
             links:
               hosts: ../../../inventory/hosts
-
+    ```
 
     Override connection options:
 
-    .. code-block:: yaml
-
+    ``` yaml
         provisioner:
           name: ansible
           connection_options:
             ansible_ssh_user: foo
             ansible_ssh_common_args: -o IdentitiesOnly=no
+    ```
+
+    Override tags:
+
+    ``` yaml
+        provisioner:
+        name: ansible
+        config_options:
+          tags:
+            run: tag1,tag2,tag3
+    ```
+
+    A typical use case is if you want to use tags within a scenario.
+    Don't forget to add a tag `always` in `converge.yml` as below.
+
+    ``` yaml
+        ---
+        - name: Converge
+          hosts: all
+          tasks:
+            - name: "Include acme.my_role_name"
+              ansible.builtin.include_role:
+                name: "acme.my_role_name"
+              tags:
+                - always
+    ```
 
     .. _`variables defined in a playbook`: https://docs.ansible.com/ansible/latest/user_guide/playbooks_variables.html#defining-variables-in-a-playbook
 
     Add arguments to ansible-playbook when running converge:
 
-    .. code-block:: yaml
-
+    ``` yaml
         provisioner:
           name: ansible
           ansible_args:
             - --inventory=mygroups.yml
             - --limit=host1,host2
+    ```
+    """
 
-    """  # noqa
-
-    def __init__(self, config):
-        """
-        Initialize a new ansible class and returns None.
+    def __init__(self, config) -> None:
+        """Initialize a new ansible class and returns None.
 
         :param config: An instance of a Molecule config.
         :return: None
         """
-        super(Ansible, self).__init__(config)
+        super().__init__(config)
 
     @property
-    def default_config_options(self):
-        """
-        Provide Default options to construct ansible.cfg and returns a dict.
-
-        :return: dict
-        """
+    def default_config_options(self) -> dict[str, Any]:
+        """Provide Default options to construct ansible.cfg and returns a dict."""
         return {
             "defaults": {
                 "ansible_managed": "Ansible managed: Do NOT edit this file manually!",
@@ -443,34 +463,46 @@ class Ansible(base.Base):
         collections_path_list = [
             util.abs_path(
                 os.path.join(
-                    self._config.scenario.config.runtime.cache_dir, "collections"
-                )
+                    self._config.scenario.config.runtime.cache_dir,
+                    "collections",
+                ),
             ),
             util.abs_path(
-                os.path.join(self._config.scenario.ephemeral_directory, "collections")
+                os.path.join(self._config.scenario.ephemeral_directory, "collections"),
             ),
         ]
         if collection_indicator in self._config.project_directory:
             collection_path, right = self._config.project_directory.rsplit(
-                collection_indicator, 1
+                collection_indicator,
+                1,
             )
             collections_path_list.append(util.abs_path(collection_path))
         collections_path_list.extend(
             [
                 util.abs_path(
-                    os.path.join(os.path.expanduser("~"), ".ansible/collections")
+                    os.path.join(os.path.expanduser("~"), ".ansible/collections"),
                 ),
                 "/usr/share/ansible/collections",
                 "/etc/ansible/collections",
-            ]
+            ],
         )
 
+        if os.environ.get("ANSIBLE_COLLECTIONS_PATH", ""):
+            collections_path_list.extend(
+                list(
+                    map(
+                        util.abs_path,
+                        os.environ["ANSIBLE_COLLECTIONS_PATH"].split(":"),
+                    ),
+                ),
+            )
+
         roles_path_list = [
             util.abs_path(
-                os.path.join(self._config.scenario.config.runtime.cache_dir, "roles")
+                os.path.join(self._config.scenario.config.runtime.cache_dir, "roles"),
             ),
             util.abs_path(
-                os.path.join(self._config.scenario.ephemeral_directory, "roles")
+                os.path.join(self._config.scenario.ephemeral_directory, "roles"),
             ),
             util.abs_path(os.path.join(self._config.project_directory, os.path.pardir)),
             util.abs_path(os.path.join(os.path.expanduser("~"), ".ansible", "roles")),
@@ -480,7 +512,7 @@ class Ansible(base.Base):
 
         if os.environ.get("ANSIBLE_ROLES_PATH", ""):
             roles_path_list.extend(
-                list(map(util.abs_path, os.environ["ANSIBLE_ROLES_PATH"].split(":")))
+                list(map(util.abs_path, os.environ["ANSIBLE_ROLES_PATH"].split(":"))),
             )
 
         env = util.merge_dicts(
@@ -498,20 +530,25 @@ class Ansible(base.Base):
                                 self._config.scenario.ephemeral_directory,
                                 "plugins",
                                 "filter",
-                            )
+                            ),
                         ),
                         util.abs_path(
                             os.path.join(
-                                self._config.project_directory, "plugins", "filter"
-                            )
+                                self._config.project_directory,
+                                "plugins",
+                                "filter",
+                            ),
                         ),
                         util.abs_path(
                             os.path.join(
-                                os.path.expanduser("~"), ".ansible", "plugins", "filter"
-                            )
+                                os.path.expanduser("~"),
+                                ".ansible",
+                                "plugins",
+                                "filter",
+                            ),
                         ),
                         "/usr/share/ansible/plugins/filter",
-                    ]
+                    ],
                 ),
             },
         )
@@ -600,10 +637,9 @@ class Ansible(base.Base):
 
     @property
     def inventory(self):
-        """
-        Create an inventory structure and returns a dict.
+        """Create an inventory structure and returns a dict.
 
-        .. code-block:: yaml
+        ``` yaml
             ungrouped:
               vars:
                 foo: bar
@@ -621,8 +657,7 @@ class Ansible(base.Base):
                   ansible_connection: docker
                 instance-2:
                   ansible_connection: docker
-
-        :return: str
+        ```
         """
         dd = self._vivify()
         for platform in self._config.platforms.instances:
@@ -683,8 +718,7 @@ class Ansible(base.Base):
         )
 
     def cleanup(self):
-        """
-        Execute `ansible-playbook` against the cleanup playbook and returns \
+        """Execute `ansible-playbook` against the cleanup playbook and returns \
         None.
 
         :return: None
@@ -696,12 +730,12 @@ class Ansible(base.Base):
         d = self._config.driver.ansible_connection_options(instance_name)
 
         return util.merge_dicts(
-            d, self._config.config["provisioner"]["connection_options"]
+            d,
+            self._config.config["provisioner"]["connection_options"],
         )
 
     def check(self):
-        """
-        Execute ``ansible-playbook`` against the converge playbook with the \
+        """Execute ``ansible-playbook`` against the converge playbook with the \
         ``--check`` flag and returns None.
 
         :return: None
@@ -711,8 +745,7 @@ class Ansible(base.Base):
         pb.execute()
 
     def converge(self, playbook=None, **kwargs):
-        """
-        Execute ``ansible-playbook`` against the converge playbook unless \
+        """Execute ``ansible-playbook`` against the converge playbook unless \
         specified otherwise and returns a string.
 
         :param playbook: An optional string containing an absolute path to a
@@ -725,8 +758,7 @@ class Ansible(base.Base):
         return pb.execute()
 
     def destroy(self):
-        """
-        Execute ``ansible-playbook`` against the destroy playbook and returns \
+        """Execute ``ansible-playbook`` against the destroy playbook and returns \
         None.
 
         :return: None
@@ -735,8 +767,7 @@ class Ansible(base.Base):
         pb.execute()
 
     def side_effect(self, action_args=None):
-        """
-        Execute ``ansible-playbook`` against the side_effect playbook and \
+        """Execute ``ansible-playbook`` against the side_effect playbook and \
         returns None.
 
         :return: None
@@ -752,8 +783,7 @@ class Ansible(base.Base):
             pb.execute()
 
     def create(self):
-        """
-        Execute ``ansible-playbook`` against the create playbook and returns \
+        """Execute ``ansible-playbook`` against the create playbook and returns \
         None.
 
         :return: None
@@ -762,8 +792,7 @@ class Ansible(base.Base):
         pb.execute()
 
     def prepare(self):
-        """
-        Execute ``ansible-playbook`` against the prepare playbook and returns \
+        """Execute ``ansible-playbook`` against the prepare playbook and returns \
         None.
 
         :return: None
@@ -772,8 +801,7 @@ class Ansible(base.Base):
         pb.execute()
 
     def syntax(self):
-        """
-        Execute ``ansible-playbook`` against the converge playbook with the \
+        """Execute ``ansible-playbook`` against the converge playbook with the \
         ``-syntax-check`` flag and returns None.
 
         :return: None
@@ -783,8 +811,7 @@ class Ansible(base.Base):
         pb.execute()
 
     def verify(self, action_args=None):
-        """
-        Execute ``ansible-playbook`` against the verify playbook and returns \
+        """Execute ``ansible-playbook`` against the verify playbook and returns \
         None.
 
         :return: None
@@ -804,19 +831,18 @@ class Ansible(base.Base):
             pb.execute()
 
     def write_config(self):
-        """
-        Write the provisioner's config file to disk and returns None.
+        """Write the provisioner's config file to disk and returns None.
 
         :return: None
         """
         template = util.render_template(
-            self._get_config_template(), config_options=self.config_options
+            self._get_config_template(),
+            config_options=self.config_options,
         )
         util.write_file(self.config_file, template)
 
     def manage_inventory(self):
-        """
-        Manage inventory for Ansible and returns None.
+        """Manage inventory for Ansible and returns None.
 
         :returns: None
         """
@@ -831,8 +857,7 @@ class Ansible(base.Base):
         return util.abs_path(os.path.join(self._config.scenario.directory, path))
 
     def _add_or_update_vars(self):
-        """
-        Create host and/or group vars and returns None.
+        """Create host and/or group vars and returns None.
 
         :returns: None
         """
@@ -857,14 +882,13 @@ class Ansible(base.Base):
                 if not os.path.isdir(util.abs_path(target_vars_directory)):
                     os.mkdir(util.abs_path(target_vars_directory))
 
-                for target in vars_target.keys():
+                for target in vars_target:
                     target_var_content = vars_target[target]
                     path = os.path.join(util.abs_path(target_vars_directory), target)
                     util.write_file(path, util.safe_dump(target_var_content))
 
     def _write_inventory(self):
-        """
-        Write the provisioner's inventory file to disk and returns None.
+        """Write the provisioner's inventory file to disk and returns None.
 
         :return: None
         """
@@ -873,8 +897,7 @@ class Ansible(base.Base):
         util.write_file(self.inventory_file, util.safe_dump(self.inventory))
 
     def _remove_vars(self):
-        """
-        Remove hosts/host_vars/group_vars and returns None.
+        """Remove hosts/host_vars/group_vars and returns None.
 
         :returns: None
         """
@@ -886,8 +909,7 @@ class Ansible(base.Base):
                 shutil.rmtree(d)
 
     def _link_or_update_vars(self):
-        """
-        Create or updates the symlink to group_vars and returns None.
+        """Create or updates the symlink to group_vars and returns None.
 
         :returns: None
         """
@@ -899,12 +921,11 @@ class Ansible(base.Base):
                 msg = f"The source path '{source}' does not exist."
                 util.sysexit_with_message(msg)
             msg = f"Inventory {source} linked to {target}"
-            LOG.info(msg)
+            LOG.debug(msg)
             os.symlink(source, target)
 
     def _get_ansible_playbook(self, playbook, verify=False, **kwargs):
-        """
-        Get an instance of AnsiblePlaybook and returns it.
+        """Get an instance of AnsiblePlaybook and returns it.
 
         :param playbook: A string containing an absolute path to a
          provisioner's playbook.
@@ -914,12 +935,14 @@ class Ansible(base.Base):
         :return: object
         """
         return ansible_playbook.AnsiblePlaybook(
-            playbook, self._config, verify, **kwargs
+            playbook,
+            self._config,
+            verify,
+            **kwargs,
         )
 
     def _verify_inventory(self):
-        """
-        Verify the inventory is valid and returns None.
+        """Verify the inventory is valid and returns None.
 
         :return: None
         """
@@ -928,8 +951,7 @@ class Ansible(base.Base):
             util.sysexit_with_message(msg)
 
     def _get_config_template(self):
-        """
-        Return a config template string.
+        """Return a config template string.
 
         :return: str
         """
@@ -943,8 +965,7 @@ class Ansible(base.Base):
 """.strip()
 
     def _vivify(self):
-        """
-        Return an autovivification default dict.
+        """Return an autovivification default dict.
 
         :return: dict
         """
@@ -959,17 +980,17 @@ class Ansible(base.Base):
     def _get_plugin_directory(self) -> str:
         return os.path.join(self.directory, "plugins")
 
-    def _get_modules_directories(self) -> List[str]:
+    def _get_modules_directories(self) -> list[str]:
         """Return list of ansilbe module includes directories.
 
         Adds modules directory from molecule and its plugins.
         """
-        paths: List[Optional[str]] = []
+        paths: list[Optional[str]] = []
         if os.environ.get("ANSIBLE_LIBRARY"):
             paths = list(map(util.abs_path, os.environ["ANSIBLE_LIBRARY"].split(":")))
 
         paths.append(
-            util.abs_path(os.path.join(self._get_plugin_directory(), "modules"))
+            util.abs_path(os.path.join(self._get_plugin_directory(), "modules")),
         )
 
         for d in drivers():
@@ -979,7 +1000,7 @@ class Ansible(base.Base):
         paths.extend(
             [
                 util.abs_path(
-                    os.path.join(self._config.scenario.ephemeral_directory, "library")
+                    os.path.join(self._config.scenario.ephemeral_directory, "library"),
                 ),
                 util.abs_path(os.path.join(self._config.project_directory, "library")),
                 util.abs_path(
@@ -988,10 +1009,10 @@ class Ansible(base.Base):
                         ".ansible",
                         "plugins",
                         "modules",
-                    )
+                    ),
                 ),
                 "/usr/share/ansible/plugins/modules",
-            ]
+            ],
         )
 
         return [path for path in paths if path is not None]
