@@ -24,11 +24,11 @@ import sys
 
 import click
 import packaging
-from ansible_compat.runtime import Runtime
 
 import molecule
 from molecule import command, logger
 from molecule.api import drivers
+from molecule.app import app
 from molecule.command.base import click_group_ex
 from molecule.config import MOLECULE_DEBUG, MOLECULE_VERBOSITY
 from molecule.console import console
@@ -60,8 +60,7 @@ def print_version(ctx, param, value):
     color = "bright_yellow" if v.is_prerelease else "green"
     msg = f"molecule [{color}]{v}[/] using python [repr.number]{sys.version_info[0]}.{sys.version_info[1]}[/] \n"
 
-    runtime = Runtime()
-    msg += f"    [repr.attrib_name]ansible[/][dim]:[/][repr.number]{runtime.version}[/]"
+    msg += f"    [repr.attrib_name]ansible[/][dim]:[/][repr.number]{app.runtime.version}[/]"
     for driver in drivers():
         msg += f"\n    [repr.attrib_name]{str(driver)}[/][dim]:[/][repr.number]{driver.version}[/][dim] from {driver.module}[/]"
         if driver.required_collections:
@@ -97,10 +96,10 @@ def print_version(ctx, param, value):
         " configurations in the specified order,"
         " and deep merge each scenario's "
         "molecule.yml on top. By default Molecule is looking for "
-        "'{}' "
+        f"'{LOCAL_CONFIG_SEARCH}' "
         "in current VCS repository and if not found it will look "
-        "in user home. ({})."
-    ).format(LOCAL_CONFIG_SEARCH, LOCAL_CONFIG),
+        f"in user home. ({LOCAL_CONFIG})."
+    ),
 )
 @click.option(
     "--env-file",
@@ -109,12 +108,15 @@ def print_version(ctx, param, value):
     help=("The file to read variables from when rendering molecule.yml. " "(.env.yml)"),
 )
 @click.option(
-    "--version", is_flag=True, callback=print_version, expose_value=False, is_eager=True
+    "--version",
+    is_flag=True,
+    callback=print_version,
+    expose_value=False,
+    is_eager=True,
 )
 @click.pass_context
 def main(ctx, debug, verbose, base_config, env_file):  # pragma: no cover
-    """
-    Molecule aids in the development and testing of Ansible roles.
+    """Molecule aids in the development and testing of Ansible roles.
 
     To enable autocomplete for a supported shell execute command below after
     replacing SHELL with either bash, zsh, or fish:
@@ -145,7 +147,6 @@ main.add_command(command.destroy.destroy)
 main.add_command(command.drivers.drivers)
 main.add_command(command.idempotence.idempotence)
 main.add_command(command.init.init)
-main.add_command(command.lint.lint)
 main.add_command(command.list.list)
 main.add_command(command.login.login)
 main.add_command(command.matrix.matrix)
