@@ -23,7 +23,7 @@ import pytest
 from molecule.command import check
 
 
-@pytest.fixture
+@pytest.fixture()
 def _patched_ansible_check(mocker):
     return mocker.patch("molecule.provisioner.ansible.Ansible.check")
 
