@@ -23,7 +23,7 @@ import pytest
 from molecule.command import login
 
 
-@pytest.fixture
+@pytest.fixture()
 def _instance(config_instance):
     config_instance.state.change_state("created", True)
 
@@ -40,7 +40,9 @@ def test_execute(mocker, _instance):
 
 @pytest.mark.skip(reason="needs rewrite after switch to delegated")
 @pytest.mark.parametrize(
-    "config_instance", ["command_driver_delegated_managed_section_data"], indirect=True
+    "config_instance",
+    ["command_driver_delegated_managed_section_data"],
+    indirect=True,
 )
 def test_execute_raises_when_not_created(patched_logger_critical, _instance):
     _instance._config.state.change_state("created", False)
@@ -48,7 +50,7 @@ def test_execute_raises_when_not_created(patched_logger_critical, _instance):
     with pytest.raises(SystemExit) as e:
         _instance.execute()
 
-    assert 1 == e.value.code
+    assert e.value.code == 1
 
     msg = "Instances not created.  Please create instances first."
     patched_logger_critical.assert_called_once_with(msg)
@@ -60,7 +62,7 @@ def test_get_hostname_does_not_match(patched_logger_critical, _instance):
     with pytest.raises(SystemExit) as e:
         _instance._get_hostname(hosts)
 
-    assert 1 == e.value.code
+    assert e.value.code == 1
 
     msg = (
         "There are no hosts that match 'invalid'.  You "
@@ -73,39 +75,40 @@ def test_get_hostname_exact_match_with_one_host(_instance):
     _instance._config.command_args = {"host": "instance-1"}
     hosts = ["instance-1"]
 
-    assert "instance-1" == _instance._get_hostname(hosts)
+    assert _instance._get_hostname(hosts) == "instance-1"
 
 
 def test_get_hostname_partial_match_with_one_host(_instance):
     _instance._config.command_args = {"host": "inst"}
     hosts = ["instance-1"]
 
-    assert "instance-1" == _instance._get_hostname(hosts)
+    assert _instance._get_hostname(hosts) == "instance-1"
 
 
 def test_get_hostname_exact_match_with_multiple_hosts(_instance):
     _instance._config.command_args = {"host": "instance-1"}
     hosts = ["instance-1", "instance-2"]
 
-    assert "instance-1" == _instance._get_hostname(hosts)
+    assert _instance._get_hostname(hosts) == "instance-1"
 
 
 def test_get_hostname_partial_match_with_multiple_hosts(_instance):
     _instance._config.command_args = {"host": "foo"}
     hosts = ["foo", "fooo"]
 
-    assert "foo" == _instance._get_hostname(hosts)
+    assert _instance._get_hostname(hosts) == "foo"
 
 
 def test_get_hostname_partial_match_with_multiple_hosts_raises(
-    patched_logger_critical, _instance
+    patched_logger_critical,
+    _instance,
 ):
     _instance._config.command_args = {"host": "inst"}
     hosts = ["instance-1", "instance-2"]
     with pytest.raises(SystemExit) as e:
         _instance._get_hostname(hosts)
 
-    assert 1 == e.value.code
+    assert e.value.code == 1
 
     msg = (
         "There are 2 hosts that match 'inst'. "
@@ -122,18 +125,19 @@ def test_get_hostname_no_host_flag_specified_on_cli(_instance):
     hosts = ["instance-1"]
     _instance._get_hostname(hosts)
 
-    assert "instance-1" == _instance._get_hostname(hosts)
+    assert _instance._get_hostname(hosts) == "instance-1"
 
 
 def test_get_hostname_no_host_flag_specified_on_cli_with_multiple_hosts_raises(
-    patched_logger_critical, _instance
+    patched_logger_critical,
+    _instance,
 ):
     _instance._config.command_args = {}
     hosts = ["instance-1", "instance-2"]
     with pytest.raises(SystemExit) as e:
         _instance._get_hostname(hosts)
 
-    assert 1 == e.value.code
+    assert e.value.code == 1
 
     msg = (
         "There are 2 running hosts. Please specify "
