@@ -22,9 +22,10 @@ import copy
 import functools
 import os
 import shutil
+from collections.abc import Generator
 from pathlib import Path
 from subprocess import CompletedProcess
-from typing import Any, Generator, Tuple
+from typing import Any
 from uuid import uuid4
 
 import pytest
@@ -42,55 +43,55 @@ def write_molecule_file(filename: str, data: Any) -> None:
     util.write_file(filename, util.safe_dump(data))
 
 
-def os_split(s: str) -> Tuple[str, ...]:
+def os_split(s: str) -> tuple[str, ...]:
     rest, tail = os.path.split(s)
     if rest in ("", os.path.sep):
         return (tail,)
-    return os_split(rest) + (tail,)
+    return (*os_split(rest), tail)
 
 
-@pytest.fixture
+@pytest.fixture()
 def _molecule_dependency_galaxy_section_data():
     return {"dependency": {"name": "galaxy"}}
 
 
-@pytest.fixture
+@pytest.fixture()
 def _molecule_driver_section_data():
     return {"driver": {"name": "delegated", "options": {"managed": True}}}
 
 
-@pytest.fixture
+@pytest.fixture()
 def _molecule_platforms_section_data():
     return {
         "platforms": [
             {"name": "instance-1", "groups": ["foo", "bar"], "children": ["child1"]},
             {"name": "instance-2", "groups": ["baz", "foo"], "children": ["child2"]},
-        ]
+        ],
     }
 
 
-@pytest.fixture
+@pytest.fixture()
 def _molecule_provisioner_section_data():
     return {
         "provisioner": {
             "name": "ansible",
             "options": {"become": True},
             "config_options": {},
-        }
+        },
     }
 
 
-@pytest.fixture
+@pytest.fixture()
 def _molecule_scenario_section_data():
     return {"scenario": {"name": "default"}}
 
 
-@pytest.fixture
+@pytest.fixture()
 def _molecule_verifier_section_data():
     return {"verifier": {"name": "ansible"}}
 
 
-@pytest.fixture
+@pytest.fixture()
 def molecule_data(
     _molecule_dependency_galaxy_section_data,
     _molecule_driver_section_data,
@@ -99,7 +100,6 @@ def molecule_data(
     _molecule_scenario_section_data,
     _molecule_verifier_section_data,
 ):
-
     fixtures = [
         _molecule_dependency_galaxy_section_data,
         _molecule_driver_section_data,
@@ -112,39 +112,42 @@ def molecule_data(
     return functools.reduce(lambda x, y: util.merge_dicts(x, y), fixtures)
 
 
-@pytest.fixture
+@pytest.fixture()
 def molecule_directory_fixture(temp_dir):
     return molecule_directory()
 
 
-@pytest.fixture
+@pytest.fixture()
 def molecule_scenario_directory_fixture(molecule_directory_fixture):
     path = molecule_scenario_directory()
     if not os.path.isdir(path):
-        os.makedirs(path)
+        os.makedirs(path, exist_ok=True)
 
     return path
 
 
-@pytest.fixture
+@pytest.fixture()
 def molecule_ephemeral_directory_fixture(molecule_scenario_directory_fixture):
     path = molecule_ephemeral_directory(str(uuid4()))
     if not os.path.isdir(path):
-        os.makedirs(path)
+        os.makedirs(path, exist_ok=True)
     yield
     shutil.rmtree(str(Path(path).parent))
 
 
-@pytest.fixture
+@pytest.fixture()
 def molecule_file_fixture(
-    molecule_scenario_directory_fixture, molecule_ephemeral_directory_fixture
+    molecule_scenario_directory_fixture,
+    molecule_ephemeral_directory_fixture,
 ):
     return molecule_file()
 
 
-@pytest.fixture
+@pytest.fixture()
 def config_instance(
-    molecule_file_fixture: str, molecule_data, request
+    molecule_file_fixture: str,
+    molecule_data,
+    request,
 ) -> Generator[config.Config, None, None]:
     mdc = copy.deepcopy(molecule_data)
     if hasattr(request, "param"):
@@ -163,47 +166,50 @@ def config_instance(
 # Mocks
 
 
-@pytest.fixture
+@pytest.fixture()
 def patched_print_debug(mocker):
     return mocker.patch("molecule.util.print_debug")
 
 
-@pytest.fixture
+@pytest.fixture()
 def patched_logger_info(mocker):
     return mocker.patch("logging.Logger.info")
 
 
-@pytest.fixture
+@pytest.fixture()
 def patched_logger_debug(mocker):
     return mocker.patch("logging.Logger.debug")
 
 
-@pytest.fixture
+@pytest.fixture()
 def patched_logger_warning(mocker):
     return mocker.patch("logging.Logger.warning")
 
 
-@pytest.fixture
+@pytest.fixture()
 def patched_logger_error(mocker):
     return mocker.patch("logging.Logger.error")
 
 
-@pytest.fixture
+@pytest.fixture()
 def patched_logger_critical(mocker):
     return mocker.patch("logging.Logger.critical")
 
 
-@pytest.fixture
+@pytest.fixture()
 def patched_run_command(mocker):
     m = mocker.patch("molecule.util.run_command")
     m.return_value = CompletedProcess(
-        args="foo", returncode=0, stdout="patched-run-command-stdout", stderr=""
+        args="foo",
+        returncode=0,
+        stdout="patched-run-command-stdout",
+        stderr="",
     )
 
     return m
 
 
-@pytest.fixture
+@pytest.fixture()
 def patched_ansible_converge(mocker):
     m = mocker.patch("molecule.provisioner.ansible.Ansible.converge")
     m.return_value = "patched-ansible-converge-stdout"
@@ -211,28 +217,28 @@ def patched_ansible_converge(mocker):
     return m
 
 
-@pytest.fixture
+@pytest.fixture()
 def patched_add_or_update_vars(mocker):
     return mocker.patch("molecule.provisioner.ansible.Ansible._add_or_update_vars")
 
 
-@pytest.fixture
+@pytest.fixture()
 def patched_ansible_galaxy(mocker):
     return mocker.patch("molecule.dependency.ansible_galaxy.AnsibleGalaxy.execute")
 
 
-@pytest.fixture
+@pytest.fixture()
 def patched_default_verifier(mocker):
     return mocker.patch("molecule.verifier.ansible.Ansible.execute")
 
 
-@pytest.fixture
+@pytest.fixture()
 def patched_scenario_setup(mocker):
     mocker.patch("molecule.config.Config.env")
 
     return mocker.patch("molecule.scenario.Scenario._setup")
 
 
-@pytest.fixture
+@pytest.fixture()
 def patched_config_validate(mocker):
     return mocker.patch("molecule.config.Config._validate")
