@@ -23,80 +23,112 @@ import pytest
 from molecule.model import schema_v3
 
 
-@pytest.fixture
+@pytest.fixture()
 def _model_driver_section_data():
     return {
         "driver": {
             "name": "delegated",
             "provider": {"name": None},
-            "options": {"managed": True, "foo": "bar"},
+            "options": {"managed": True},
             "ssh_connection_options": ["foo", "bar"],
             "safe_files": ["foo", "bar"],
-        }
+        },
     }
 
 
 @pytest.mark.parametrize("_config", ["_model_driver_section_data"], indirect=True)
 def test_driver(_config):
-    assert {} == schema_v3.validate(_config)
+    assert not schema_v3.validate(_config)
 
 
-@pytest.fixture
+@pytest.fixture()
 def _model_driver_errors_section_data():
     return {
         "driver": {
-            "name": int(),
-            "provider": {"name": int(), "foo": "bar"},
-            "options": {"managed": str()},
-            "ssh_connection_options": [int()],
-            "safe_files": [int()],
-        }
+            "name": 0,
+        },
+    }
+
+
+@pytest.fixture()
+def _model_driver_errors_section_data_no_prefix():
+    return {
+        "driver": {
+            "name": "random_name",
+        },
     }
 
 
 @pytest.mark.parametrize(
-    "_config", ["_model_driver_errors_section_data"], indirect=True
+    "_config",
+    [
+        "_model_driver_errors_section_data",
+        "_model_driver_errors_section_data_no_prefix",
+    ],
+    indirect=True,
 )
 def test_driver_has_errors(_config):
-    x = {
-        "driver": [
-            {
-                "safe_files": [{0: ["must be of string type"]}],
-                "options": [{"managed": ["must be of boolean type"]}],
-                "ssh_connection_options": [{0: ["must be of string type"]}],
-                "name": ["must be of string type"],
-                "provider": [{"name": ["must be of string type"]}],
-            }
-        ]
-    }
+    base_error_msg = "is not one of ['azure', 'ec2', 'delegated', 'docker', 'containers', 'openstack', 'podman', 'vagrant', 'digitalocean', 'gce', 'libvirt', 'lxd', 'molecule-*', 'molecule_*', 'custom-*', 'custom_*']"
 
-    assert x == schema_v3.validate(_config)
+    driver_name = str(_config["driver"]["name"])
+    if type(_config["driver"]["name"]) is str:
+        # add single quotes for string
+        driver_name = f"'{driver_name}'"
+
+    error_msg = [" ".join((driver_name, base_error_msg))]
+    assert error_msg == schema_v3.validate(_config)
 
 
-@pytest.fixture
+@pytest.fixture()
 def _model_driver_provider_name_nullable_section_data():
     return {"driver": {"provider": {"name": None}}}
 
 
 @pytest.mark.parametrize(
-    "_config", ["_model_driver_provider_name_nullable_section_data"], indirect=True
+    "_config",
+    ["_model_driver_provider_name_nullable_section_data"],
+    indirect=True,
 )
 def test_driver_provider_name_nullable(_config):
-    assert {} == schema_v3.validate(_config)
+    assert not schema_v3.validate(_config)
 
 
-@pytest.fixture
+@pytest.fixture()
 def _model_driver_allows_delegated_section_data():
     return {"driver": {"name": "delegated"}}
 
 
+@pytest.fixture()
+def _model_driver_allows_molecule_section_data1():
+    return {"driver": {"name": "molecule-test_driver.name"}}
+
+
+@pytest.fixture()
+def _model_driver_allows_molecule_section_data2():
+    return {"driver": {"name": "molecule_test_driver.name"}}
+
+
+@pytest.fixture()
+def _model_driver_allows_custom_section_data1():
+    return {"driver": {"name": "custom-test_driver.name"}}
+
+
+@pytest.fixture()
+def _model_driver_allows_custom_section_data2():
+    return {"driver": {"name": "custom_test_driver.name"}}
+
+
 ###
 @pytest.mark.parametrize(
     "_config",
     [
         ("_model_driver_allows_delegated_section_data"),
+        ("_model_driver_allows_molecule_section_data1"),
+        ("_model_driver_allows_molecule_section_data2"),
+        ("_model_driver_allows_custom_section_data2"),
+        ("_model_driver_allows_custom_section_data1"),
     ],
     indirect=True,
 )
 def test_driver_allows_name(_config):
-    assert {} == schema_v3.validate(_config)
+    assert not schema_v3.validate(_config)
