@@ -30,76 +30,72 @@ LOG = logging.getLogger(__name__)
 
 
 class Testinfra(Verifier):
-    """
-    `Testinfra`_ is no longer the default test verifier since version 3.0.
+    """`Testinfra`_ is no longer the default test verifier since version 3.0.
 
     Additional options can be passed to ``testinfra`` through the options
     dict.  Any option set in this section will override the defaults.
 
-    .. note::
+    !!! note
 
         Molecule will remove any options matching '^[v]+$', and pass ``-vvv``
         to the underlying ``pytest`` command when executing ``molecule
         --debug``.
 
-    .. code-block:: yaml
-
+    ``` yaml
         verifier:
           name: testinfra
           options:
             n: 1
+    ```
 
     The testing can be disabled by setting ``enabled`` to False.
 
-    .. code-block:: yaml
-
+    ``` yaml
         verifier:
           name: testinfra
           enabled: False
+    ```
 
     Environment variables can be passed to the verifier.
 
-    .. code-block:: yaml
-
+    ``` yaml
         verifier:
           name: testinfra
           env:
             FOO: bar
+    ```
 
     Change path to the test directory.
 
-    .. code-block:: yaml
-
+    ``` yaml
         verifier:
           name: testinfra
           directory: /foo/bar/
+    ```
 
     Additional tests from another file or directory relative to the scenario's
     tests directory (supports regexp).
 
-    .. code-block:: yaml
-
+    ``` yaml
         verifier:
           name: testinfra
           additional_files_or_dirs:
             - ../path/to/test_1.py
             - ../path/to/test_2.py
             - ../path/to/directory/*
-
+    ```
     .. _`Testinfra`: https://testinfra.readthedocs.io
     """
 
-    def __init__(self, config=None):
-        """
-        Set up the requirements to execute ``testinfra`` and returns None.
+    def __init__(self, config=None) -> None:
+        """Set up the requirements to execute ``testinfra`` and returns None.
 
         :param config: An instance of a Molecule config.
         :return: None
         """
-        super(Testinfra, self).__init__(config)
+        super().__init__(config)
         self._testinfra_command = None
-        if config:
-            self._tests = self._get_tests()
+        self._tests = []  # type: ignore
 
     @property
     def name(self):
@@ -149,35 +145,36 @@ class Testinfra(Verifier):
         return files_list
 
     def bake(self):
-        """
-        Bake a ``testinfra`` command so it's ready to execute and returns None.
+        """Bake a ``testinfra`` command so it's ready to execute and returns None.
 
         :return: None
         """
         options = self.options
         verbose_flag = util.verbose_flag(options)
-        args = verbose_flag + self.additional_files_or_dirs
+        args = verbose_flag
 
         self._testinfra_command = util.BakedCommand(
             cmd=["pytest", *util.dict2args(options), *self._tests, *args],
             cwd=self._config.scenario.directory,
             env=self.env,
         )
-        # print(self._testinfra_command.cmd)
 
-    def execute(self):
+    def execute(self, action_args=None):
         if not self.enabled:
             msg = "Skipping, verifier is disabled."
             LOG.warning(msg)
             return
 
+        if self._config:
+            self._tests = self._get_tests(action_args)
+        else:
+            self._tests = []
         if not len(self._tests) > 0:
             msg = "Skipping, no tests found."
             LOG.warning(msg)
             return
 
-        if self._testinfra_command is None:
-            self.bake()
+        self.bake()
 
         msg = f"Executing Testinfra tests found in {self.directory}/..."
         LOG.info(msg)
@@ -189,25 +186,39 @@ class Testinfra(Verifier):
         else:
             util.sysexit(result.returncode)
 
-    def _get_tests(self):
-        """
-        Walk the verifier's directory for tests and returns a list.
+    def _get_tests(self, action_args=None):
+        """Walk the verifier's directory for tests and returns a list.
 
         :return: list
         """
-        return sorted(
-            [
-                filename
-                for filename in util.os_walk(
-                    self.directory, "test_*.py", followlinks=True
+        if action_args:
+            tests = []
+            for arg in action_args:
+                args_tests = list(
+                    util.os_walk(
+                        os.path.join(self._config.scenario.directory, arg),
+                        "test_*.py",
+                        followlinks=True,
+                    ),
                 )
-            ]
-        )
+                tests.extend(args_tests)
+            return sorted(tests)
+        else:
+            return sorted(
+                list(
+                    util.os_walk(
+                        self.directory,
+                        "test_*.py",
+                        followlinks=True,
+                    ),
+                )
+                + self.additional_files_or_dirs,
+            )
 
     def schema(self):
         return {
             "verifier": {
                 "type": "dict",
                 "schema": {"name": {"type": "string", "allowed": ["testinfra"]}},
-            }
+            },
         }
